summaryrefslogtreecommitdiffstats
path: root/drivers/staging/unisys/visorbus/visorchipset.c
diff options
context:
space:
mode:
authorSameer Wadgaonkar2017-08-22 19:27:34 +0200
committerGreg Kroah-Hartman2017-08-23 00:14:55 +0200
commit51c0f81cca9dbe01c1bada3db62daef839431175 (patch)
treef3e2d24feaad6811d4a40a6c84b7b9a4d51d39a4 /drivers/staging/unisys/visorbus/visorchipset.c
parentstaging: unisys: visorbus: Get rid of passthrough function visorchipset_bus_d... (diff)
downloadkernel-qcow2-linux-51c0f81cca9dbe01c1bada3db62daef839431175.tar.gz
kernel-qcow2-linux-51c0f81cca9dbe01c1bada3db62daef839431175.tar.xz
kernel-qcow2-linux-51c0f81cca9dbe01c1bada3db62daef839431175.zip
staging: unisys: visorbus: Get rid of passthrough function visorchipset_device_create
The function visorchipset_device_create just called create_visor_device, we can just combine it with create_visor_device. Signed-off-by: Sameer Wadgaonkar <sameer.wadgaonkar@unisys.com> Signed-off-by: David Kershner <david.kershner@unisys.com> Reviewed-by: Tim Sell <timothy.sell@unisys.com> Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
Diffstat (limited to 'drivers/staging/unisys/visorbus/visorchipset.c')
-rw-r--r--drivers/staging/unisys/visorbus/visorchipset.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/drivers/staging/unisys/visorbus/visorchipset.c b/drivers/staging/unisys/visorbus/visorchipset.c
index a478533a231c..153c7e5ad79a 100644
--- a/drivers/staging/unisys/visorbus/visorchipset.c
+++ b/drivers/staging/unisys/visorbus/visorchipset.c
@@ -833,8 +833,8 @@ static int visorbus_device_create(struct controlvm_message *inmsg)
sizeof(struct controlvm_message_header));
dev_info->pending_msg_hdr = pmsg_hdr;
}
- /* visorchipset_device_create will send response */
- err = visorchipset_device_create(dev_info);
+ /* create_visor_device will send response */
+ err = create_visor_device(dev_info);
if (err)
goto err_destroy_visorchannel;